const SCALE_X = 4330 / 866;
const SCALE_Y = 2964 / 593;

// Called when the user clicks on the map.
const ShowClosestBuilding = (evt) => {
  const toggle = document.getElementsByName('toggle');
  const svg = document.getElementById('svg')
  const r = svg.getClientRects()[0];
  const x = SCALE_X * (evt.clientX - r.x);
  const y = SCALE_Y * (evt.clientY - r.y);

  if (toggle[0].checked) {
    fetch("/findBuildingsByPosition?x=" + x + "&y=" + y).then((res) => {
      if (res.status === 200) {
        res.json().then((data) => {
          ShowResults(data.results);
        });
      }
    })
  } else {
    fetch("/findFriendsByPosition?x=" + x + "&y=" + y).then((res) => {
      if (res.status === 200) {
        res.json().then((data) => {
          ShowResults(data.results);
        });
      }
    })
  }
};

// Cleared when the user clicks the search button.
const HandleSearch = (_) => {
  const elem = document.getElementById('text');
  const text = elem.value.trim();
  const searchSetting = document.getElementById('search');

  switch (searchSetting.value) {
    case "buildings":
      HandleBuilding(text);
      break;
    case "friend":
      HandleFriend(text);
      break;
    case "time":
      HandleTime(text);
      break;
  }
};

// Called when the user clicks the search button for a buildings query.
const HandleBuilding = (text) => {
  if (text.length > 0) {
    fetch("/findByName?text=" + encodeURIComponent(text)).then((res) => {
      if (res.status === 200) {
        res.json().then((data) => {
          ShowResults(data.results);
        });
      }
    })
  }
}

// Called when the user clicks the search button for the friend query.
const HandleFriend = (text) => {
  if (text.length > 0) {
    fetch("/findByFriend?text=" + encodeURIComponent(text)).then((res) => {
      if (res.status === 200) {
        res.json().then((data) => {
          ShowResults(data.results);
        });
      }
    })
  }
};

// Called when the user clicks the show button for the time query.
const HandleTime = (text) => {
  if (text.length > 0) {
    fetch("/findByTime?text=" + encodeURIComponent(text)).then((res) => {
      if (res.status === 200) {
        res.json().then((data) => {
          ShowResults(data.results);
        });
      }
    })
  }
};

// Called when the user clicks the clear button.
const HandleClear = (_) => {
  const elem1 = document.getElementById('search');
  elem1.value = "";
  const elem2 = document.getElementById('text');
  elem2.value = "";
  ShowResults([]);
};


const COLORS = [
  ["rgb(204, 66, 72)", "rgba(204, 66, 72, 0.25)"],
  ["rgb(50, 85, 165)", "rgba(50, 85, 165, 0.25)"],
  ["rgb(150, 66, 157)", "rgba(150, 66, 157, 0.25)"],
  ["rgb(237, 182, 17)", "rgba(237, 182, 17, 0.25)"],
  ["rgb(22, 117, 62)", "rgba(22, 117, 62, 0.25)"],
  ["rgb(218, 126, 41)", "rgba(218, 126, 41, 0.25)"],
  ["rgb(211, 24, 189)", "rgba(211, 24, 189, 0.25)"],
];

// Updates the UI to show the given results.
const ShowResults = (results) => {
  const svgElem = document.getElementById('svg');
  const svgHtml = [
    '<image href="campus_map.jpg" width="4330" height="2964"/>'
  ];
  for (let i = 0; i < results.length; i++) {
    const [c, d] = COLORS[i % COLORS.length];
    const x = results[i].x + 0;  // :)
    const y = results[i].y + 0;
    svgHtml.push(
      `<circle cx="${x}" cy="${y}" stroke="${c}" r="100" stroke-width="10" fill="${d}"/>`);
  }
  svgElem.innerHTML = svgHtml.join("\n");

  const resElem = document.getElementById('results');
  const resHtml = [];
  if (results.length > 0) {
    resHtml.push(`<h3>Results</h3>`);
    if (Object.keys(results[0]).length === 4) {
      for (let i = 0; i < results.length; i++) {
        const c = COLORS[i][0];
        const short = results[i].shortName;
        const long = results[i].longName;
        resHtml.push('<p class="result">' +
            `<span class="color" style="background-color: ${c};">&nbsp;</span>` +
            `<span class="text">${short}: ${long}</span></p>`);
      }
    } else {
      for (let i = 0; i < results.length; i++) {
        const c = COLORS[i % COLORS.length][0];
        const short = results[i].shortName;
        const friend = results[i].friend;
        const time = results[i].time;
        resHtml.push('<p class="result">' +
            `<span class="color" style="background-color: ${c};">&nbsp;</span>` +
            `<span class="text">${friend} at ${time} in ${short}</span></p>`);
      }
    }
  }
  resElem.innerHTML = resHtml.join("\n");
};